//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Core/Contrib/GISASSpecularContribution.cpp
//! @brief     Implements class GISASSpecularContribution.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Core/Contrib/GISASSpecularContribution.h"
#include "Base/Util/Assert.h"
#include "Resample/Element/DiffuseElement.h"
#include "Resample/Flux/ScalarFlux.h"

void GISASSpecularContribution::compute(DiffuseElement& ele) const
{
    if (!ele.isSpecular())
        return;

    const auto* flux = dynamic_cast<const ScalarFlux*>(ele.fluxIn(0));
    ASSERT(flux);
    complex_t R = flux->getScalarR();

    double sin_alpha_i = std::abs(std::sin(ele.getAlphaI()));
    if (sin_alpha_i == 0.0) {
        ele.setIntensity(0);
        return;
    }
    const double solid_angle = ele.solidAngle();
    if (solid_angle <= 0.0)
        return;
    const double intensity = std::norm(R) * sin_alpha_i / solid_angle;
    ele.setIntensity(intensity);
}
