//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Instrument/RectangularDetectorItem.h
//! @brief     Defines class RectangularDetectorItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_INSTRUMENT_RECTANGULARDETECTORITEM_H
#define BORNAGAIN_GUI_MODEL_INSTRUMENT_RECTANGULARDETECTORITEM_H

#include "GUI/Model/Instrument/DetectorItems.h"

class BasicAxisItem;
class VectorItem;
class ComboProperty;

class BA_CORE_API_ RectangularDetectorItem : public DetectorItem {
private:
    static constexpr auto P_X_AXIS{"X axis"};
    static constexpr auto P_Y_AXIS{"Y axis"};
    static constexpr auto P_ALIGNMENT{"Alignment"};
    static constexpr auto P_NORMAL{"Normal vector"};
    static constexpr auto P_DIRECTION{"Direction vector"};
    static constexpr auto P_U0{"u0"};
    static constexpr auto P_V0{"v0"};
    static constexpr auto P_DBEAM_U0{"u0 (dbeam)"};
    static constexpr auto P_DBEAM_V0{"v0 (dbeam)"};
    static constexpr auto P_DISTANCE{"Distance"};

public:
    static constexpr auto M_TYPE{"RectangularDetector"};

    RectangularDetectorItem();

    void setDetectorAlignment(const QString& alignment);

    int xSize() const override;
    int ySize() const override;
    void setXSize(int nx) override;
    void setYSize(int ny) override;

    const BasicAxisItem* xAxisItem() const;
    BasicAxisItem* xAxisItem();
    const BasicAxisItem* yAxisItem() const;
    BasicAxisItem* yAxisItem();

    static bool isAlignmentPropertyName(const QString& name);
    SessionItem* alignmentItem() const;
    ComboProperty alignment() const;
    void setAlignment(const ComboProperty& alignment);

    VectorItem* normalVectorItem() const;
    void setNormalVector(const R3& normal);

    VectorItem* directionVectorItem() const;
    void setDirectionVector(const R3& direction);

    SessionItem* u0Item() const;
    double u0() const;
    void setU0(double u0);

    SessionItem* v0Item() const;
    double v0() const;
    void setV0(double v0);

    SessionItem* directBeamU0Item() const;
    double directBeamU0() const;
    void setDirectBeamU0(double dbeam_u0);

    SessionItem* directBeamV0Item() const;
    double directBeamV0() const;
    void setDirectBeamV0(double dbeam_v0);

    SessionItem* distanceItem() const;
    double distance() const;
    void setDistance(double distance);

private:
    std::unique_ptr<IDetector2D> createDomainDetector() const override;
    void update_properties_appearance();
    R3 normalVector() const;
    R3 directionVector() const;

    bool m_is_constructed;
};

#endif // BORNAGAIN_GUI_MODEL_INSTRUMENT_RECTANGULARDETECTORITEM_H
