//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/Lattice2DItems.h
//! @brief     Defines classes Lattice2DItems
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_SAMPLE_LATTICE2DITEMS_H
#define BORNAGAIN_GUI_MODEL_SAMPLE_LATTICE2DITEMS_H

#include "GUI/Model/Session/SessionItem.h"

class Lattice2D;
class DoubleDescriptor;

class Lattice2DItem : public SessionItem {
private:
    static constexpr auto P_LATTICE_ROTATION_ANGLE{"Xi"};

protected:
    explicit Lattice2DItem(const QString& modelType);

public:
    virtual std::unique_ptr<Lattice2D> createLattice() const = 0;
    double unitCellArea() const;

    SessionItem* latticeRotationAngleItem() const;
    DoubleDescriptor latticeRotationAngle() const;
    void setLatticeRotationAngle(double angle);
};

class BasicLattice2DItem : public Lattice2DItem {
private:
    static constexpr auto P_LATTICE_LENGTH1{"LatticeLength1"};
    static constexpr auto P_LATTICE_LENGTH2{"LatticeLength2"};
    static constexpr auto P_LATTICE_ANGLE{"Alpha"};

public:
    static constexpr auto M_TYPE{"BasicLattice2D"};

    BasicLattice2DItem();
    std::unique_ptr<Lattice2D> createLattice() const override;

    DoubleDescriptor latticeLength1() const;
    void setLatticeLength1(double length1);

    DoubleDescriptor latticeLength2() const;
    void setLatticeLength2(double length2);

    DoubleDescriptor latticeAngle() const;
    void setLatticeAngle(double angle);
};

class SquareLattice2DItem : public Lattice2DItem {
private:
    static constexpr auto P_LATTICE_LENGTH{"LatticeLength"};

public:
    static constexpr auto M_TYPE{"SquareLattice2D"};

    SquareLattice2DItem();
    std::unique_ptr<Lattice2D> createLattice() const override;

    DoubleDescriptor latticeLength() const;
    void setLatticeLength(double length);
};

class HexagonalLattice2DItem : public Lattice2DItem {
private:
    static constexpr auto P_LATTICE_LENGTH{"LatticeLength"};

public:
    static constexpr auto M_TYPE{"HexagonalLattice2D"};

    HexagonalLattice2DItem();
    std::unique_ptr<Lattice2D> createLattice() const override;

    DoubleDescriptor latticeLength() const;
    void setLatticeLength(double length);
};

#endif // BORNAGAIN_GUI_MODEL_SAMPLE_LATTICE2DITEMS_H
