//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Session/ModelUtils.cpp
//! @brief     Implements ModelUtils namespace
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Session/ModelUtils.h"
#include "GUI/Model/Session/SessionModel.h"
#include <QAbstractItemModel>
#include <QModelIndex>

QStringList GUI::Model::ItemUtils::topItemNames(const SessionModel* model, const QString& modelType)
{
    QStringList result;

    for (auto* item : model->topItems())
        if (modelType.isEmpty() || modelType == item->modelType())
            result.append(item->itemName());

    return result;
}

QString GUI::Model::ItemUtils::suggestName(const QStringList& existingNames, const QString& name)
{
    int newNumber = -1;
    QRegExp regexp(R"(\((\d+)\))");

    QString baseName = name;
    if (regexp.indexIn(baseName) >= 0) {
        newNumber = regexp.cap(1).toInt();
        baseName.replace(regexp.cap(0), "");
        baseName = baseName.trimmed();
    }

    for (const auto& name : existingNames) {
        if (name == baseName)
            newNumber = std::max(newNumber, 2);
        else if (regexp.indexIn(name) >= 0)
            newNumber = std::max(newNumber, regexp.cap(1).toInt() + 1);
    }

    if (newNumber == -1)
        return baseName;

    return QString("%1 (%2)").arg(baseName).arg(newNumber);
}
