//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Types/VectorItem.h
//! @brief     Defines class VectorItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_TYPES_VECTORITEM_H
#define BORNAGAIN_GUI_MODEL_TYPES_VECTORITEM_H

#include "GUI/Model/Session/SessionItem.h"
#include <heinz/Vectors3D.h>

class BA_CORE_API_ VectorItem : public SessionItem {
private:
    static constexpr auto P_X{"X"};
    static constexpr auto P_Y{"Y"};
    static constexpr auto P_Z{"Z"};

public:
    static constexpr auto M_TYPE{"Vector"};

    VectorItem();

    double x() const;
    void setX(double value);
    SessionItem* xItem() const;

    double y() const;
    void setY(double value);
    SessionItem* yItem() const;

    double z() const;
    void setZ(double value);
    SessionItem* zItem() const;

    void setXYZ(double x_value, double y_value, double z_value);

    R3 getVector() const;
    void setVector(const R3& vec);

private:
    void updateLabel();
};

#endif // BORNAGAIN_GUI_MODEL_TYPES_VECTORITEM_H
