//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Instrument/DetectorAlignmentEditor.h
//! @brief     A widget for editing the alignment of a detector
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_INSTRUMENT_DETECTORALIGNMENTEDITOR_H
#define BORNAGAIN_GUI_VIEW_INSTRUMENT_DETECTORALIGNMENTEDITOR_H

#include <QWidget>

class QComboBox;
class QStackedLayout;

class DetectorAlignmentForm;
class RectangularDetectorItem;

#include <array>

/// Widget for selecting the alignment of a detector (combo box) and input of the corresponding
/// values

class DetectorAlignmentEditor : public QWidget {
public:
    DetectorAlignmentEditor(QWidget* parent = nullptr, Qt::WindowFlags f = Qt::WindowFlags());
    void setItem(RectangularDetectorItem* item);
    void clearItem();

private slots:
    void onAlignmentSelected(int index);

private:
    QComboBox* m_combo;
    QStackedLayout* m_stack;
    std::array<DetectorAlignmentForm*, 5> m_forms;
    RectangularDetectorItem* m_item;
};

#endif // BORNAGAIN_GUI_VIEW_INSTRUMENT_DETECTORALIGNMENTEDITOR_H
