//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Realspace/RealSpaceBuilder.h
//! @brief     Defines class RealSpaceBuilder
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_REALSPACE_REALSPACEBUILDER_H
#define BORNAGAIN_GUI_VIEW_REALSPACE_REALSPACEBUILDER_H

#include "GUI/View/Realspace/RealSpaceBuilderUtils.h"
#include "GUI/ba3d/view/camera.h"
#include <QVector3D>
#include <QWidget>

class SessionItem;
class LayerItem;
class MultiLayerItem;
class ParticleLayoutItem;
class Shape3D;
struct SceneGeometry;
class Particle3DContainer;

namespace GUI::RealSpace {

class Model;
}


class RealSpaceBuilder : public QWidget {
    Q_OBJECT

public:
    RealSpaceBuilder(const MaterialModel* materialModel, QWidget* parent = nullptr);

    ~RealSpaceBuilder() override;

    void
    populate(GUI::RealSpace::Model* model, const SessionItem& item,
             const SceneGeometry& sceneGeometry,
             const GUI::RealSpace::Camera::Position& cameraPosition =
                 GUI::RealSpace::Camera::Position(GUI::RealSpace::Vector3D(0, -200, 120), // eye
                                                  GUI::RealSpace::Vector3D(0, 0, 0),      // center
                                                  GUI::RealSpace::Vector3D::_z))          // up
        const;
    void populateMultiLayer(GUI::RealSpace::Model* model, const MultiLayerItem& mlayerItem,
                            const SceneGeometry& sceneGeometry, const QVector3D& origin = {}) const;

    void populateLayer(GUI::RealSpace::Model* model, const LayerItem& layerItem,
                       const SceneGeometry& sceneGeometry, const QVector3D& origin = {},
                       bool isTopLayer = false) const;

    void populateLayout(GUI::RealSpace::Model* model, const ParticleLayoutItem& layoutItem,
                        const SceneGeometry& sceneGeometry, const QVector3D& origin = {}) const;

    void populateParticleFromParticleItem(GUI::RealSpace::Model* model,
                                          const SessionItem& particleItem) const;

    void populateParticleFromParticle3DContainer(GUI::RealSpace::Model* model,
                                                 const Particle3DContainer& particle3DContainer,
                                                 const QVector3D& lattice_position = {}) const;

private:
    std::unique_ptr<GUI::RealSpace::BuilderUtils> m_builderUtils;
};

#endif // BORNAGAIN_GUI_VIEW_REALSPACE_REALSPACEBUILDER_H
