//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/SampleDesigner/MesoCrystalForm.h
//! @brief     Defines class MesoCrystalForm
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_SAMPLEDESIGNER_MESOCRYSTALFORM_H
#define BORNAGAIN_GUI_VIEW_SAMPLEDESIGNER_MESOCRYSTALFORM_H

#include <QGroupBox>

class MesoCrystalItem;
class QAction;
class SampleEditorController;
class QComboBox;
class ItemWithParticles;
class QFormLayout;

//! Form for editing a mesocrystal
class MesoCrystalForm : public QGroupBox {
public:
    MesoCrystalForm(QWidget* parent, MesoCrystalItem* item, SampleEditorController* ec,
                    bool allowRemove = true);

    void enableStructureEditing(bool b);
    MesoCrystalItem* mesoCrystalItem() const;
    void createBasisWidgets();

private:
    QComboBox* createBasisCombo(QWidget* parent, ItemWithParticles* current);

    void onBasisComboChanged();

    QFormLayout* m_layout;
    MesoCrystalItem* m_item;
    QAction* m_removeAction = nullptr;
    SampleEditorController* m_ec;
    QComboBox* m_basisCombo;
    int m_rowOfBasisTypeCombo;
};


#endif // BORNAGAIN_GUI_VIEW_SAMPLEDESIGNER_MESOCRYSTALFORM_H
