//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/SampleDesigner/SampleView.h
//! @brief     Defines class SampleView
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_SAMPLEDESIGNER_SAMPLEVIEW_H
#define BORNAGAIN_GUI_VIEW_SAMPLEDESIGNER_SAMPLEVIEW_H

#include <QMainWindow>

class DocksController;
class ProjectDocument;
class RealSpacePanel;
class SessionItem;
class MultiLayerItem;

class SampleView : public QMainWindow {
    Q_OBJECT
public:
    enum ESubWindows { PYTHONPANEL, REALSPACEPANEL, SAMPLE_LIST };

    SampleView(QWidget* parent, ProjectDocument* document);

    void toggleRealSpaceView();
    void fillViewMenu(QMenu* menu);

private:
    void resetLayout();
    void updateSingleSampleMode();

    //! Show the item in the real space view
    //!
    //! If the real space view is not visible at the moment, it will be shown.
    void onRequestViewInRealSpace(SessionItem* itemToView);

    DocksController* m_docks = nullptr;
    ProjectDocument* m_document = nullptr;
    RealSpacePanel* m_realSpacePanel = nullptr;
};

#endif // BORNAGAIN_GUI_VIEW_SAMPLEDESIGNER_SAMPLEVIEW_H
