//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Resample/DWBA/DWBA_Pol.h
//! @brief     Defines class DWBA_Pol.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_RESAMPLE_DWBA_DWBA_POL_H
#define BORNAGAIN_RESAMPLE_DWBA_DWBA_POL_H

#include "Resample/DWBA/IDWBA.h"
#include <Eigen/Core>

//! Provides polarized DWBA computation for given IFormFactor.

class DWBA_Pol : public IDWBA {
public:
    DWBA_Pol(const IFormFactor& ff, size_t i_layer);
    DWBA_Pol(const IFormFactor& ff);
    ~DWBA_Pol() override;

    //! Returns the coherent sum of the four DWBA terms for polarized scattering.
    Eigen::Matrix2cd coherentPolFF(const DiffuseElement& ele) const;

    friend class TestPolarizedDWBATerm;
};

#endif // BORNAGAIN_RESAMPLE_DWBA_DWBA_POL_H
#endif // USER_API
