//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Resample/Interparticle/SSCAStrategy.h
//! @brief     Defines class SSCAStrategy.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_RESAMPLE_INTERPARTICLE_SSCASTRATEGY_H
#define BORNAGAIN_RESAMPLE_INTERPARTICLE_SSCASTRATEGY_H

#include "Resample/Interparticle/IInterparticleStrategy.h"

class InterferenceRadialParaCrystal;
class DiffuseElement;

//! Strategy class to compute the total scattering from a particle layout
//! in the size-spacing correlation approximation.

class SSCAStrategy : public IInterparticleStrategy {
public:
    SSCAStrategy(const std::vector<std::unique_ptr<const CoherentFFSum>>& weighted_formfactors,
                 const InterferenceRadialParaCrystal* iff, SimulationOptions sim_params,
                 bool polarized, double kappa);

private:
    double scalarCalculation(const DiffuseElement& ele) const override;
    double polarizedCalculation(const DiffuseElement& ele) const override;

    complex_t getCharacteristicSizeCoupling(
        double qp, const std::vector<std::unique_ptr<const CoherentFFSum>>& ff_wrappers) const;
    complex_t calculatePositionOffsetPhase(double qp, double radial_extension) const;

    const std::unique_ptr<InterferenceRadialParaCrystal> m_iff;
    const double m_kappa;
    const double m_mean_radius;
};

#endif // BORNAGAIN_RESAMPLE_INTERPARTICLE_SSCASTRATEGY_H
#endif // USER_API
