//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/Scattering/FormFactorDecoratorRotation.h
//! @brief     Defines class FormFactorDecoratorRotation.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_SAMPLE_SCATTERING_FORMFACTORDECORATORROTATION_H
#define BORNAGAIN_SAMPLE_SCATTERING_FORMFACTORDECORATORROTATION_H

#include "Base/Vector/Transform3D.h"
#include "Sample/Scattering/IFormFactorDecorator.h"

class IRotation;

//! Equips a form factor with a rotation.

class FormFactorDecoratorRotation : public IFormFactorDecorator {
public:
    inline static const std::string class_name = "FormFactorDecoratorRotation";
    std::string className() const final { return class_name; }

    //! Constructor, setting form factor and rotation.
    FormFactorDecoratorRotation(const IFormFactor& ff, const IRotation& rotation);

    FormFactorDecoratorRotation* clone() const override;

    double bottomZ(const IRotation* rotation) const override;

    double topZ(const IRotation* rotation) const override;

    complex_t theFF(const WavevectorInfo& wavevectors) const override;
#ifndef SWIG
    Eigen::Matrix2cd thePolFF(const WavevectorInfo& wavevectors) const override;
#endif

private:
    Transform3D m_transform;
    //! Private constructor for cloning.
    FormFactorDecoratorRotation(const IFormFactor& ff, const Transform3D& transform);
};

#endif // BORNAGAIN_SAMPLE_SCATTERING_FORMFACTORDECORATORROTATION_H
#endif // USER_API
