//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/StandardSamples/ParaCrystalBuilder.h
//! @brief     Defines classes of ParaCrystalBuilder family.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_SAMPLE_STANDARDSAMPLES_PARACRYSTALBUILDER_H
#define BORNAGAIN_SAMPLE_STANDARDSAMPLES_PARACRYSTALBUILDER_H

class MultiLayer;

#include <memory>

class IFTDistribution2D;
class FTDistribution2DComponents;

//! @ingroup standard_samples
//! Builds sample: cylinders with 1DDL structure factor (IsGISAXS example #4).

namespace ExemplarySamples {

MultiLayer* createRadialParaCrystal();

} // namespace ExemplarySamples

//! Builds sample: basic two dimensional paracrystal with various probability
//! distribution functions (PDF's). They are initialized via component service.
//! @ingroup standard_samples

namespace ExemplarySamples {

MultiLayer* createBasic2DParaCrystalWithFTDis(const IFTDistribution2D* pdf2);

} // namespace ExemplarySamples

//! Builds sample: cylinders with 2DDL structure factor (IsGISAXS example #4).
//! @ingroup standard_samples

namespace ExemplarySamples {

MultiLayer* createHexParaCrystal();

} // namespace ExemplarySamples

//! @ingroup standard_samples
//! Builds sample: 2D paracrystal lattice (IsGISAXS example #8).

namespace ExemplarySamples {

MultiLayer* createRectParaCrystal();

} // namespace ExemplarySamples

#endif // BORNAGAIN_SAMPLE_STANDARDSAMPLES_PARACRYSTALBUILDER_H
#endif // USER_API
