#include "GUI/Model/Sample/ParticleCompositionItem.h"
#include "GUI/Model/Sample/ParticleItem.h"
#include "GUI/Model/Sample/SampleModel.h"
#include "GUI/Model/Session/SessionItemUtils.h"
#include "GUI/Model/Types/DoubleDescriptor.h"
#include "Tests/GTestWrapper/google_test.h"

using namespace GUI::Session::ItemUtils;

class TestParticleItem : public ::testing::Test {
};

TEST_F(TestParticleItem, InitialState)
{
    SampleModel model;
    auto* item = model.insertItem<ParticleItem>();

    EXPECT_EQ(item->displayName(), "Particle");
    EXPECT_EQ(item->displayName(), item->itemName());
    // P_FORM_FACTOR, P_MATERIAL, P_ABUNDANCE, P_POSITION
    EXPECT_EQ(item->children().size(), 4);
    EXPECT_TRUE(ItemWithParticles::isTransformationTagName(item->defaultTag()));

    GroupItem* group = item->formFactorItem();
    EXPECT_EQ(group->displayName(), "Form Factor");
    EXPECT_EQ(group->children().size(), 1);
}

TEST_F(TestParticleItem, compositionContext)
{
    SampleModel model;
    auto* particle = model.insertItem<ParticleItem>();
    particle->setAbundance(0.2);
    EXPECT_TRUE(particle->abundanceItem()->isEnabled());
    EXPECT_EQ(particle->abundance(), 0.2);

    // adding particle to composition, checking that abundance is default
    auto* composition = model.insertItem<ParticleCompositionItem>();
    composition->addParticle(particle);
    EXPECT_FALSE(particle->abundanceItem()->isEnabled());
    EXPECT_EQ(particle->abundance(), 1.0);

    // removing particle, checking that abundance is enabled again
    composition->takeRow(ParentRow(*particle));
    EXPECT_TRUE(particle->abundanceItem()->isEnabled());
    delete particle;
}
