#include "Sample/Particle/ParticleComposition.h"
#include "Base/Math/Constants.h"
#include "Sample/HardParticle/FormFactorFullSphere.h"
#include "Sample/Material/MaterialFactoryFuncs.h"
#include "Sample/Particle/Particle.h"
#include "Sample/Scattering/Rotations.h"
#include "Tests/GTestWrapper/google_test.h"

class ParticleCompositionTest : public ::testing::Test {
};

TEST_F(ParticleCompositionTest, ParticleCompositionDefaultConstructor)
{
    std::unique_ptr<ParticleComposition> composition(new ParticleComposition());
    std::vector<R3> positions;
    positions.emplace_back(R3(0.0, 0.0, 0.0));
    EXPECT_EQ(0u, composition->nbrParticles());
}

TEST_F(ParticleCompositionTest, ParticleCompositionClone)
{
    ParticleComposition composition;
    R3 position = R3(1.0, 1.0, 1.0);
    Material material = HomogeneousMaterial("Vacuum", 0.0, 0.0);
    FormFactorFullSphere ff(5.);
    Particle particle(material, ff);
    composition.addParticle(particle, position);

    std::unique_ptr<ParticleComposition> clone(composition.clone());
    std::vector<const INode*> children = clone->getChildren();
    EXPECT_EQ(children.size(), 1u);
    const auto* p_particle = dynamic_cast<const IParticle*>(children[0]);
    EXPECT_EQ(p_particle->rotation(), nullptr);
    EXPECT_EQ(p_particle->particlePosition(), position);
}
